package com.ruoyi.business.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.TbUserCompanyRecordMapper;
import com.ruoyi.business.domain.TbUserCompanyRecord;
import com.ruoyi.business.service.ITbUserCompanyRecordService;
import com.ruoyi.common.core.text.Convert;

/**
 * 公司的搜索记录Service业务层处理
 * 
 * @author xiatao
 * @date 2022-01-18
 */
@Service
public class TbUserCompanyRecordServiceImpl implements ITbUserCompanyRecordService 
{
    @Autowired
    private TbUserCompanyRecordMapper tbUserCompanyRecordMapper;

    /**
     * 查询公司的搜索记录
     * 
     * @param companyRecordId 公司的搜索记录主键
     * @return 公司的搜索记录
     */
    @Override
    public TbUserCompanyRecord selectTbUserCompanyRecordByCompanyRecordId(Long companyRecordId)
    {
        return tbUserCompanyRecordMapper.selectTbUserCompanyRecordByCompanyRecordId(companyRecordId);
    }

    /**
     * 查询公司的搜索记录列表
     * 
     * @param tbUserCompanyRecord 公司的搜索记录
     * @return 公司的搜索记录
     */
    @Override
    public List<TbUserCompanyRecord> selectTbUserCompanyRecordList(TbUserCompanyRecord tbUserCompanyRecord)
    {
        return tbUserCompanyRecordMapper.selectTbUserCompanyRecordList(tbUserCompanyRecord);
    }

    /**
     * 新增公司的搜索记录
     * 
     * @param tbUserCompanyRecord 公司的搜索记录
     * @return 结果
     */
    @Override
    public int insertTbUserCompanyRecord(TbUserCompanyRecord tbUserCompanyRecord)
    {
        return tbUserCompanyRecordMapper.insertTbUserCompanyRecord(tbUserCompanyRecord);
    }

    /**
     * 修改公司的搜索记录
     * 
     * @param tbUserCompanyRecord 公司的搜索记录
     * @return 结果
     */
    @Override
    public int updateTbUserCompanyRecord(TbUserCompanyRecord tbUserCompanyRecord)
    {
        return tbUserCompanyRecordMapper.updateTbUserCompanyRecord(tbUserCompanyRecord);
    }

    /**
     * 批量删除公司的搜索记录
     * 
     * @param companyRecordIds 需要删除的公司的搜索记录主键
     * @return 结果
     */
    @Override
    public int deleteTbUserCompanyRecordByCompanyRecordIds(String companyRecordIds)
    {
        return tbUserCompanyRecordMapper.deleteTbUserCompanyRecordByCompanyRecordIds(Convert.toStrArray(companyRecordIds));
    }

    /**
     * 删除公司的搜索记录信息
     * 
     * @param companyRecordId 公司的搜索记录主键
     * @return 结果
     */
    @Override
    public int deleteTbUserCompanyRecordByCompanyRecordId(Long companyRecordId)
    {
        return tbUserCompanyRecordMapper.deleteTbUserCompanyRecordByCompanyRecordId(companyRecordId);
    }
}
