package com.ruoyi.business.service.impl;

import java.util.Date;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.TbUserConfigMapper;
import com.ruoyi.business.domain.TbUserConfig;
import com.ruoyi.business.service.ITbUserConfigService;
import com.ruoyi.common.core.text.Convert;

/**
 * 用户设置Service业务层处理
 * 
 * @author xiatao
 * @date 2022-01-18
 */
@Service
public class TbUserConfigServiceImpl implements ITbUserConfigService 
{
    @Autowired
    private TbUserConfigMapper tbUserConfigMapper;

    /**
     * 查询用户设置
     * 
     * @param userId 用户设置主键
     * @return 用户设置
     */
    @Override
    public TbUserConfig selectTbUserConfigByUserId(Long userId)
    {
        return tbUserConfigMapper.selectTbUserConfigByUserId(userId);
    }

    /**
     * 查询用户设置列表
     * 
     * @param tbUserConfig 用户设置
     * @return 用户设置
     */
    @Override
    public List<TbUserConfig> selectTbUserConfigList(TbUserConfig tbUserConfig)
    {
        return tbUserConfigMapper.selectTbUserConfigList(tbUserConfig);
    }

    /**
     * 新增用户设置
     * 
     * @param tbUserConfig 用户设置
     * @return 结果
     */
    @Override
    public int insertTbUserConfig(TbUserConfig tbUserConfig)
    {
        tbUserConfig.setCreateTime(DateUtils.getNowDate());
        return tbUserConfigMapper.insertTbUserConfig(tbUserConfig);
    }

    /**
     * 修改用户设置
     * 
     * @param tbUserConfig 用户设置
     * @return 结果
     */
    @Override
    public int updateTbUserConfig(TbUserConfig tbUserConfig)
    {
        tbUserConfig.setUpdateTime(DateUtils.getNowDate());
        return tbUserConfigMapper.updateTbUserConfig(tbUserConfig);
    }

    /**
     * 批量删除用户设置
     * 
     * @param userIds 需要删除的用户设置主键
     * @return 结果
     */
    @Override
    public int deleteTbUserConfigByUserIds(String userIds)
    {
        return tbUserConfigMapper.deleteTbUserConfigByUserIds(Convert.toStrArray(userIds));
    }

    /**
     * 删除用户设置信息
     * 
     * @param userId 用户设置主键
     * @return 结果
     */
    @Override
    public int deleteTbUserConfigByUserId(Long userId)
    {
        return tbUserConfigMapper.deleteTbUserConfigByUserId(userId);
    }

}
